==> authress_sdk-1.1.15-py3-none-any.whl: authress_sdk/models/__init__.py <==
# coding: utf-8

# flake8: noqa

from __future__ import absolute_import

# import models into model package
from authress_sdk.models.access_record import AccessRecord
from authress_sdk.models.access_record_account import AccessRecordAccount
from authress_sdk.models.access_record_collection import AccessRecordCollection
from authress_sdk.models.access_record_resources import AccessRecordResources
from authress_sdk.models.access_record_statements import AccessRecordStatements
from authress_sdk.models.access_record_users import AccessRecordUsers
from authress_sdk.models.access_record_group import AccessRecordGroup
from authress_sdk.models.account import Account
from authress_sdk.models.account_collection import AccountCollection
from authress_sdk.models.claim_request import ClaimRequest
from authress_sdk.models.claim_response import ClaimResponse
from authress_sdk.models.client import Client
from authress_sdk.models.client_access_key import ClientAccessKey
from authress_sdk.models.client_collection import ClientCollection
from authress_sdk.models.client_options import ClientOptions
from authress_sdk.models.identity import Identity
from authress_sdk.models.identity_collection import IdentityCollection
from authress_sdk.models.identity_request import IdentityRequest
from authress_sdk.models.user_resources import UserResources
from authress_sdk.models.user_permissions import UserPermissions
from authress_sdk.models.permission_object import PermissionObject
from authress_sdk.models.resource_permission import ResourcePermission
from authress_sdk.models.resource_permission_collection import ResourcePermissionCollection
from authress_sdk.models.resource_permission_permissions import ResourcePermissionPermissions

==> authress_sdk-2.0.23-py3-none-any.whl: authress_sdk/models/__init__.py <==
# coding: utf-8

# flake8: noqa

from __future__ import absolute_import

# import models into model package
from authress_sdk.models.access_record import AccessRecord
from authress_sdk.models.access_record_account import AccessRecordAccount
from authress_sdk.models.access_record_collection import AccessRecordCollection
from authress_sdk.models.access_record_resource import AccessRecordResource
from authress_sdk.models.access_record_statement import AccessRecordStatement
from authress_sdk.models.access_record_user import AccessRecordUser
from authress_sdk.models.access_record_group import AccessRecordGroup
from authress_sdk.models.account import Account
from authress_sdk.models.account_collection import AccountCollection
from authress_sdk.models.claim_request import ClaimRequest
from authress_sdk.models.claim_response import ClaimResponse
from authress_sdk.models.client import Client
from authress_sdk.models.client_access_key import ClientAccessKey
from authress_sdk.models.client_collection import ClientCollection
from authress_sdk.models.client_options import ClientOptions
from authress_sdk.models.identity import Identity
from authress_sdk.models.identity_collection import IdentityCollection
from authress_sdk.models.identity_request import IdentityRequest
from authress_sdk.models.user_resources import UserResources
from authress_sdk.models.user_permissions import UserPermissions
from authress_sdk.models.permission_object import PermissionObject
from authress_sdk.models.resource_permission import ResourcePermission
from authress_sdk.models.resource_permission_collection import ResourcePermissionCollection
from authress_sdk.models.resource_permission_object import ResourcePermissionObject
